@@ -59,8 +59,8 @@ DJANGO_APPS = (
     'django.contrib.staticfiles',
     'django.contrib.admin',
     'django.contrib.humanize',
-    'dal',
-    'dal_select2',
+    #'dal',
+    #'dal_select2',
     'djcelery',
     'multiselectfield',
     'xhtml2pdf',
