@@ -19,7 +19,7 @@ EXTRA_MODULES = (
     # 'django_msp_controldeacceso',
     # 'django_msp_facturaglobal',
     # 'django_msp_importa_inventario',
-    # 'django_msp_sms',
+    'django_msp_sms',
     # 'djmicrosip_actualizarcosto'
     # 'djmicrosip_cambiaprecio_sincosto',
     # 'djmicrosip_cargos_cxp',
@@ -44,9 +44,10 @@ EXTRA_MODULES = (
     # 'agregar_precio_lista',
     'djmicrosip_orden_trabajo',
     # 'djmicrosip_reportesmaquila',
-    # 'djmicrosip_clasificadores',
+    'djmicrosip_clasificadores',
     # 'djmicrosip_enviar_ventas',
     'djlicencias_sic',
+    'djenviowhatsapp_sic',
 )
 
 import djcelery
