@@ -1,4 +1,4 @@
-from dal import autocomplete
+#from dal import autocomplete
 from django.conf.urls.static import static
 #autocomplete.autodiscover()
 
