@@ -13,7 +13,7 @@ def add_debug_apps():
 
     # ADD API
     new_path = "{}\{}".format(REPOSITORIES_PATH, 'django-microsip-api')
-    print new_path
+    print (new_path)
     sys.path.append(new_path)
 
     # ADD APPS
